@@ -87,7 +87,9 @@ func (r *ReconcileClusterLogging) Reconcile(request reconcile.Request) (reconcil
 		return reconcile.Result{}, nil
 	}
 
-	err = k8shandler.Reconcile(instance, r.client)
+	if err = k8shandler.Reconcile(instance, r.client); err != nil {
+		logrus.Error(err, "Error reconciling clusterlogging instance")
+	}
 
 	if result, err := r.updateStatus(instance); err != nil {
 		return result, err
