@@ -26,9 +26,6 @@ func (clusterRequest *ClusterLoggingRequest) CreateOrUpdateCuration() (err error
 
 	cluster := clusterRequest.Cluster
 	if cluster.Spec.Curation == nil || cluster.Spec.Curation.Type == "" {
-		if err = clusterRequest.removeCurator(); err != nil {
-			return
-		}
 		return nil
 	}
 	if cluster.Spec.Curation.Type == logging.CurationTypeCurator {
@@ -55,14 +52,9 @@ func (clusterRequest *ClusterLoggingRequest) CreateOrUpdateCuration() (err error
 			return fmt.Errorf("Failed to get status for Curator: %v", err)
 		}
 
-		printUpdateMessage := true
 		retryErr := retry.RetryOnConflict(retry.DefaultRetry, func() error {
 
 			if !compareCuratorStatus(curatorStatus, cluster.Status.Curation.CuratorStatus) {
-				if printUpdateMessage {
-					logrus.Info("Updating status of Curator")
-					printUpdateMessage = false
-				}
 				cluster.Status.Curation.CuratorStatus = curatorStatus
 				return clusterRequest.UpdateStatus(cluster)
 			}
